@@ -20,7 +20,7 @@ package MongoDB::Collection;
 # ABSTRACT: A MongoDB Collection
 
 use version;
-our $VERSION = 'v1.2.3';
+our $VERSION = 'v1.4.0';
 
 use MongoDB::Error;
 use MongoDB::IndexView;
@@ -1117,6 +1117,7 @@ sub distinct {
 #pod =method parallel_scan
 #pod
 #pod     @result_objs = $collection->parallel_scan(10);
+#pod     @result_objs = $collection->parallel_scan(10, $options );
 #pod
 #pod Returns one or more L<MongoDB::QueryResult> objects to scan the collection in
 #pod parallel. The argument is the maximum number of L<MongoDB::QueryResult> objects
@@ -1128,22 +1129,27 @@ sub distinct {
 #pod B<Note>: the server may return fewer cursors than requested, depending on the
 #pod underlying storage engine and resource availability.
 #pod
+#pod A hash reference of options may be provided. Valid keys include:
+#pod
+#pod =for :list
+#pod * C<maxTimeMS> – the maximum amount of time in milliseconds to allow the
+#pod   command to run.  (Note, this will be ignored for servers before version 3.4.)
+#pod
 #pod =cut
 
 sub parallel_scan {
-    my ( $self, $num_cursors, $opts ) = @_;
+    my ( $self, $num_cursors, $options ) = @_;
     unless (defined $num_cursors && $num_cursors == int($num_cursors)
         && $num_cursors > 0 && $num_cursors <= 10000
     ) {
         MongoDB::UsageError->throw( "first argument to parallel_scan must be a positive integer between 1 and 10000" )
     }
-    $opts = ref $opts eq 'HASH' ? $opts : { };
-
-    my $db   = $self->database;
+    $options = ref $options eq 'HASH' ? $options : { };
 
     my $op = MongoDB::Op::_ParallelScan->_new(
         %{ $self->_op_args },
         num_cursors     => $num_cursors,
+        options         => $options,
     );
 
     my $result = $self->client->send_read_op( $op );
@@ -1226,8 +1232,8 @@ sub drop {
 #pod =method ordered_bulk
 #pod
 #pod     $bulk = $coll->ordered_bulk;
-#pod     $bulk->insert( $doc1 );
-#pod     $bulk->insert( $doc2 );
+#pod     $bulk->insert_one( $doc1 );
+#pod     $bulk->insert_one( $doc2 );
 #pod     ...
 #pod     $result = $bulk->execute;
 #pod
@@ -1552,17 +1558,17 @@ sub batch_insert {
     my ( $self, $documents, $opts ) = @_;
 
     my $op = MongoDB::Op::_BatchInsert->_new(
-        db_name       => $self->database->name,
-        coll_name     => $self->name,
-        bson_codec    => $self->bson_codec,
         documents     => $documents,
-        write_concern => $self->_dynamic_write_concern($opts),
         check_keys    => 0,
         ordered       => 1,
+        %{ $_[0]->_op_args },
+        write_concern => $self->_dynamic_write_concern($opts),
     );
 
     my $result = $self->client->send_write_op($op);
 
+    return if $result->isa("MongoDB::UnacknowledgedResult");
+
     my @ids;
     my $inserted_ids = $result->inserted_ids;
     for my $k ( sort { $a <=> $b } keys %$inserted_ids ) {
@@ -1829,7 +1835,7 @@ MongoDB::Collection - A MongoDB Collection
 
 =head1 VERSION
 
-version v1.2.3
+version v1.4.0
 
 =head1 SYNOPSIS
 
@@ -1881,7 +1887,7 @@ are recommended:
     use Safe::Isa; # provides $_isa
 
     try {
-        $coll->insert( $doc )
+        $coll->insert_one( $doc )
     }
     catch {
         if ( $_->$_isa("MongoDB::DuplicateKeyError" ) {
@@ -2542,6 +2548,7 @@ details.
 =head2 parallel_scan
 
     @result_objs = $collection->parallel_scan(10);
+    @result_objs = $collection->parallel_scan(10, $options );
 
 Returns one or more L<MongoDB::QueryResult> objects to scan the collection in
 parallel. The argument is the maximum number of L<MongoDB::QueryResult> objects
@@ -2553,6 +2560,16 @@ appear only once in one of the cursors' result sets.
 B<Note>: the server may return fewer cursors than requested, depending on the
 underlying storage engine and resource availability.
 
+A hash reference of options may be provided. Valid keys include:
+
+=over 4
+
+=item *
+
+C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command to run.  (Note, this will be ignored for servers before version 3.4.)
+
+=back
+
 =head2 rename
 
     $newcollection = $collection->rename("mynewcollection");
@@ -2572,8 +2589,8 @@ Deletes a collection as well as all of its indexes.
 =head2 ordered_bulk
 
     $bulk = $coll->ordered_bulk;
-    $bulk->insert( $doc1 );
-    $bulk->insert( $doc2 );
+    $bulk->insert_one( $doc1 );
+    $bulk->insert_one( $doc2 );
     ...
     $result = $bulk->execute;
 
@@ -2762,7 +2779,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by MongoDB, Inc..
+This software is Copyright (c) 2016 by MongoDB, Inc.
 
 This is free software, licensed under:
 
