@@ -17,10 +17,10 @@
 package MongoDB::GridFS::File;
 
 
-# ABSTRACT: A Mongo GridFS file
+# ABSTRACT: A Mongo GridFS file (DEPRECATED)
 
 use version;
-our $VERSION = 'v1.2.3';
+our $VERSION = 'v1.4.0';
 
 use MongoDB::Error;
 use IO::File;
@@ -159,11 +159,11 @@ __END__
 
 =head1 NAME
 
-MongoDB::GridFS::File - A Mongo GridFS file
+MongoDB::GridFS::File - A Mongo GridFS file (DEPRECATED)
 
 =head1 VERSION
 
-version v1.2.3
+version v1.4.0
 
 =head1 SYNOPSIS
 
@@ -228,6 +228,13 @@ of bytes written.
 Return the number of bytes specified from the offset specified.  If no
 C<$length> or C<$offset> are given, the entire file is returned.
 
+=head1 DEPRECATION
+
+B<Note>: This class has been deprecated in favor of
+L<MongoDB::GridFSBucket> and its related upload and download classes.  This
+class will be removed in a future release and you are encouraged to migrate
+your applications to L<MongoDB::GridFSBucket>.
+
 =head1 AUTHORS
 
 =over 4
@@ -252,7 +259,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by MongoDB, Inc..
+This software is Copyright (c) 2016 by MongoDB, Inc.
 
 This is free software, licensed under:
 
