@@ -19,7 +19,7 @@ package MongoDB::Op::_Delete;
 # Encapsulate a delete operation; returns a MongoDB::DeleteResult
 
 use version;
-our $VERSION = 'v1.2.3';
+our $VERSION = 'v1.4.0';
 
 use Moo;
 
@@ -69,7 +69,7 @@ has just_one => (
 
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
-  MongoDB::Role::_WriteOp
+  MongoDB::Role::_WriteCommand
 );
 
 sub execute {
@@ -83,7 +83,20 @@ sub execute {
     my $op_doc = { q => $filter, limit => $self->just_one ? 1 : 0 };
 
     return (
-        $link->does_write_commands
+        ! $self->write_concern->is_acknowledged
+        ? (
+            $self->_send_legacy_op_noreply(
+                $link,
+                MongoDB::_Protocol::write_delete(
+                    $self->full_name,
+                    $self->bson_codec->encode_one( $self->filter ),
+                    { just_one => $self->just_one ? 1 : 0 }
+                ),
+                $op_doc,
+                "MongoDB::DeleteResult",
+            )
+        )
+        : $link->does_write_commands
         ? (
             $self->_send_write_command(
                 $link,
