@@ -19,7 +19,7 @@ package MongoDB::Op::_ParallelScan;
 # Encapsulate code path for parallelCollectionScan commands
 
 use version;
-our $VERSION = 'v1.2.3';
+our $VERSION = 'v1.4.0';
 
 use Moo;
 
@@ -27,6 +27,7 @@ use MongoDB::Op::_Command;
 use MongoDB::Error;
 
 use Types::Standard qw(
+    HashRef
     Int
     Str
 );
@@ -41,6 +42,12 @@ has num_cursors => (
     isa => Int,
 );
 
+has options => (
+    is      => 'ro',
+    required => 1,
+    isa => HashRef,
+);
+
 has db_name => (
     is       => 'ro',
     required => 1,
@@ -66,6 +73,7 @@ sub execute {
         numCursors             => $self->num_cursors,
         ($link->accepts_wire_version(4) ?
             @{ $self->read_concern->as_args } : () ),
+        %{$self->options},
     ];
 
     my $op = MongoDB::Op::_Command->_new(
