@@ -19,7 +19,7 @@ package MongoDB::Op::_Update;
 # Encapsulate an update operation; returns a MongoDB::UpdateResult
 
 use version;
-our $VERSION = 'v1.2.3';
+our $VERSION = 'v1.4.0';
 
 use Moo;
 
@@ -85,7 +85,7 @@ has upsert => (
 
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
-  MongoDB::Role::_WriteOp
+  MongoDB::Role::_WriteCommand
   MongoDB::Role::_UpdatePreEncoder
   MongoDB::Role::_BypassValidation
 );
@@ -107,7 +107,24 @@ sub execute {
         upsert => $self->upsert ? $true : $false,
     };
 
-    return $link->does_write_commands
+    return ! $self->write_concern->is_acknowledged
+      ? (
+        $self->_send_legacy_op_noreply(
+            $link,
+            MongoDB::_Protocol::write_update(
+                $self->full_name,
+                $self->bson_codec->encode_one( $orig_op->{q}, { invalid_chars => '' } ),
+                $self->_pre_encode_update( $link, $orig_op->{u}, $self->is_replace )->{bson},
+                {
+                    upsert => $orig_op->{upsert},
+                    multi  => $orig_op->{multi},
+                },
+            ),
+            $orig_op,
+            "MongoDB::UpdateResult"
+        )
+      )
+      : $link->does_write_commands
       ? (
         $self->_send_write_command(
             $self->_maybe_bypass(
