@@ -19,7 +19,7 @@ package MongoDB::Role::_InsertPreEncoder;
 # MongoDB interface for pre-encoding and validating docs to insert
 
 use version;
-our $VERSION = 'v1.2.3';
+our $VERSION = 'v1.4.0';
 
 use Moo::Role;
 use MongoDB::Error;
@@ -57,10 +57,9 @@ sub _pre_encode_insert {
         }
     );
 
-    return MongoDB::BSON::_EncodedDoc->_new(
-        bson => $bson_doc,
-        metadata => { _id => $id },
-    );
+    # manually bless for speed
+    return bless { bson => $bson_doc, metadata => { _id => $id } },
+      "MongoDB::BSON::_EncodedDoc";
 }
 
 1;
