@@ -19,7 +19,7 @@ package MongoDB::Role::_ReadOp;
 # MongoDB role for read ops that provides read preference
 
 use version;
-our $VERSION = 'v1.2.3';
+our $VERSION = 'v1.4.0';
 
 use Moo::Role;
 
@@ -34,8 +34,6 @@ use Types::Standard qw(
 );
 use namespace::clean;
 
-with 'MongoDB::Role::_DatabaseOp';
-
 # PERL-573 Would like to refactor to remove Maybe types for
 # read_preference and read_concern
 has read_preference => (
@@ -48,4 +46,8 @@ has read_concern => (
     isa => Maybe [ReadConcern],
 );
 
+with $_ for qw(
+  MongoDB::Role::_BSONCodec
+);
+
 1;
