@@ -19,7 +19,7 @@ package MongoDB::Role::_UpdatePreEncoder;
 # MongoDB interface for pre-encoding and validating update/replace docs
 
 use version;
-our $VERSION = 'v1.2.3';
+our $VERSION = 'v1.4.0';
 
 use Moo::Role;
 use MongoDB::Error;
@@ -67,11 +67,8 @@ sub _pre_encode_update {
         );
     }
 
-
-    return MongoDB::BSON::_EncodedDoc->_new(
-        bson => $bson_doc,
-        metadata => {},
-    );
+    # manually bless for speed
+    return bless { bson => $bson_doc, metadata => {} }, "MongoDB::BSON::_EncodedDoc";
 }
 
 1;
